Function amazon_sp_aplus_content::apis::aplus_content_api::validate_content_document_asin_relations
source · [−]pub async fn validate_content_document_asin_relations(
configuration: &Configuration,
marketplace_id: &str,
post_content_document_request: PostContentDocumentRequest,
asin_set: Option<Vec<String>>
) -> Result<ValidateContentDocumentAsinRelationsResponse, Error>Expand description
Checks if the A+ Content document is valid for use on a set of ASINs. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 10 | 10 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.